@@ -1,13 +1,13 @@
 ;;; olivetti.el --- Minor mode for a nice writing environment -*- lexical-binding: t; -*-
 
-;; Copyright (c) 2014-2019  Paul Wiliam Rankin
+;; Copyright (c) 2014-2019  Paul W. Rankin
 ;; Copyright (c) 2019       Free Software Foundation, Inc.
-;; Copyright (c) 2019-2020  Paul Wiliam Rankin
+;; Copyright (c) 2019-2021  Paul W. Rankin
 
-;; Author: William Rankin <william@bydasein.com>
+;; Author: Paul W. Rankin <pwr@bydasein.com>
 ;; Keywords: wp, text
-;; Version: 1.11.1
-;; Package-Requires: ((emacs "24.5"))
+;; Version: 1.11.3
+;; Package-Requires: ((emacs "24.4"))
 ;; URL: https://github.com/rnkn/olivetti
 
 ;; This file is not part of GNU Emacs.
@@ -27,43 +27,52 @@
 
 ;;; Commentary:
 
-;; # Olivetti #
+;; Olivetti
+;; ========
 
 ;; A simple Emacs minor mode for a nice writing environment.
 
-;; ## Features ##
+;; Features
+;; --------
 
-;; - Set a desired text body width to automatically resize window margins to
-;;   keep the text comfortably in the middle of the window.
-;; - Text body width can be the number of characters (an integer) or a fraction
-;;   of the window width (a float between 0.0 and 1.0).
-;; - Interactively change body width with:
-;;   olivetti-shrink C-c { { { ...
-;;   olivetti-expand C-c } } } ...
-;;   olivetti-set-width C-c \
-;; - If olivetti-body-width is an integer, the text body width will scale with
-;;   use of text-scale-mode, whereas if a fraction (float) then the text body
-;;   width will remain at that fraction.
-;; - Optionally remember the state of visual-line-mode on entry and recall its
-;;   state on exit.
+;;  - Set a desired text body width to automatically resize window margins
+;;    to keep the text comfortably in the middle of the window.
+;;  - Text body width can be the number of characters (an integer) or a
+;;    fraction of the window width (a float between 0.0 and 1.0).
+;;  - Interactively change body width with:
+;;    olivetti-shrink C-c { { { ...
+;;    olivetti-expand C-c } } } ...
+;;    olivetti-set-width C-c \
+;;  - If olivetti-body-width is an integer, the text body width will
+;;    scale with use of text-scale-mode, whereas if a fraction (float) then
+;;    the text body width will remain at that fraction.
+;;  - Optionally remember the state of visual-line-mode on entry and
+;;    recall its state on exit.
 
-;; Olivetti keeps everything it does buffer-local, so you can write prose in one
-;; buffer and code in another, side-by-side in the same frame. For those looking
-;; for a hardcore distraction-free writing mode with a much larger scope, I
-;; recommend writeroom-mode: https://github.com/joostkremers/writeroom-mode.
+;; Olivetti keeps everything it does buffer-local, so you can write prose
+;; in one buffer and code in another, side-by-side in the same frame. For
+;; those looking for a hardcore distraction-free writing mode with a much
+;; larger scope, I recommend writeroom-mode:
+;; <https://github.com/joostkremers/writeroom-mode>.
 
-;; ## Requirements ##
 
-;; - Emacs 24.5
+;; Requirements
+;; ------------
 
-;; ## Installation ##
+;;  - Emacs 24.5
+;;  - seq 2.20 (part of Emacs 25 and later)
+
+
+;; Installation
+;; ------------
 
 ;; The latest stable release of Olivetti is available via
-;; [MELPA-stable]. First, add MELPA-stable to your package archives:
+;; [MELPA-stable][1]. First, add MELPA-stable to your package archives:
 
 ;;     M-x customize-option RET package-archives RET
 
-;; Insert an entry named melpa-stable with the URL https://stable.melpa.org/packages/.
+;; Insert an entry named melpa-stable with URL:
+;; https://stable.melpa.org/packages/
 
 ;; You can then find the latest stable version of olivetti in the
 ;; list returned by:
@@ -71,12 +80,14 @@
 ;;     M-x list-packages RET
 
 ;; If you prefer the latest but perhaps unstable version, do the above
-;; using [MELPA].
+;; using [MELPA][2].
 
-;; ## Advanced Installation ##
 
-;; Download the [latest release], move this file into your load-path and
-;; add to your init.el file:
+;; Advanced Installation
+;; ---------------------
+
+;; Download the latest tagged release, move this file into your load-path
+;; and add to your init.el file:
 
 ;;     (require 'olivetti)
 
@@ -85,16 +96,18 @@
 
 ;;     git clone https://github.com/rnkn/olivetti.git
 
-;; [melpa]: https://melpa.org/#/olivetti "MELPA"
-;; [melpa-stable]: https://stable.melpa.org/#/olivetti "MELPA-stable"
-;; [latest release]: https://github.com/rnkn/olivetti/releases/latest "Olivetti latest release"
 
-;; ## Contributing ##
+;; Bugs and Feature Requests
+;; -------------------------
 
-;; Please report bugs and request features at:
-;; https://github.com/rnkn/olivetti/issues
+;; Send me an email (address in the package header). For bugs, please
+;; ensure you can reproduce with:
 
-;; ## Hints ##
+;;     $ emacs -Q -l olivetti.el
+
+
+;; Hints
+;; -----
 
 ;; To always use a different width for a specific file, set a File
 ;; Variable:
@@ -103,6 +116,10 @@
 
 ;; See (info "(emacs) File Variables")
 
+
+;; [1]: https://stable.melpa.org/#/olivetti
+;; [2]: https://melpa.org/#/olivetti
+
 
 ;;; Code:
 
@@ -338,7 +355,8 @@ If prefixed with ARG, incrementally decrease."
           (map (cdr olivetti-mode-map)))
       (when (< 0 (length prefix-keys))
         (mapc (lambda (k) (setq map (assq k map))) prefix-keys)
-        (when (consp map) (set-transient-map (cdr map) t))))))
+        (setq map (cdr-safe map))
+        (when (keymapp map) (set-transient-map map t))))))
 
 (defun olivetti-shrink (&optional arg)
   "Incrementally decrease the value of `olivetti-body-width'.
